<?php
/**
* CleanWP functions and definitions.
*
* @link https://developer.wordpress.org/themes/basics/theme-functions/
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2022 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

define( 'CLEANWP_PROURL', 'https://themesdna.com/cleanwp-pro-wordpress-theme/' );
define( 'CLEANWP_CONTACTURL', 'https://themesdna.com/contact/' );
define( 'CLEANWP_THEMEOPTIONSDIR', get_template_directory() . '/admin' );
require_once( CLEANWP_THEMEOPTIONSDIR . '/customizer.php' );

function cleanwp_get_option($option) {
    $cleanwp_options = get_option('cleanwp_options');
    if ((is_array($cleanwp_options)) && (array_key_exists($option, $cleanwp_options))) {
        return $cleanwp_options[$option];
    }
    else {
        return '';
    }
}

if ( ! function_exists( 'cleanwp_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function cleanwp_setup() {

    global $wp_version;

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on CleanWP, use a find and replace
     * to change 'cleanwp' to the name of your theme in all the template files.
     */
    load_theme_textdomain( 'cleanwp', get_template_directory() . '/languages' );

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
     */
    add_theme_support( 'post-thumbnails' );

    if ( function_exists( 'add_image_size' ) ) {
        add_image_size( 'cleanwp-larger-image',  1072, 9999, false );
        add_image_size( 'cleanwp-large-image',  731, 9999, false );
        add_image_size( 'cleanwp-autoh-image',  240, 9999, false );
    }

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus( array(
    'primary' => esc_html__('Primary Menu', 'cleanwp')
    ) );

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    $markup = array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption', 'navigation-widgets' );
    add_theme_support( 'html5', $markup );

    add_theme_support( 'custom-logo', array(
        'height'      => 90,
        'width'       => 400,
        'flex-height' => true,
        'flex-width'  => true,
        'header-text' => array( 'site-title', 'site-description' ),
    ) );

    // Support for Custom Header
    add_theme_support( 'custom-header', apply_filters( 'cleanwp_custom_header_args', array(
    'default-image'          => '',
    'default-text-color'     => '000000',
    'width'                  => 1100,
    'height'                 => 275,
    'flex-height'            => true,
        'wp-head-callback'       => 'cleanwp_header_style',
        'uploads'                => true,
    ) ) );

    // Set up the WordPress core custom background feature.
    $background_args = array(
            'default-color'          => '717171',
            'default-image'          => '',
            'default-repeat'         => 'repeat',
            'default-position-x'     => 'left',
            'wp-head-callback'       => '_custom_background_cb',
            'admin-head-callback'    => 'admin_head_callback_func',
            'admin-preview-callback' => 'admin_preview_callback_func',
    );
    add_theme_support( 'custom-background', apply_filters( 'cleanwp_custom_background_args', $background_args) );

    // Support for Custom Editor Style
    add_editor_style( 'css/editor-style.css' );

    // Add support for responsive embedded content.
    add_theme_support( 'responsive-embeds' );

    // Add support for Default Block Styles.
    add_theme_support( 'wp-block-styles' );

    if ( !(cleanwp_get_option('enable_widgets_block_editor')) ) {
        remove_theme_support( 'widgets-block-editor' );
    }

}
endif;
add_action( 'after_setup_theme', 'cleanwp_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function cleanwp_content_width() {
    $content_width = 731;

    if ( ( ! is_active_sidebar( 'main-sidebar' ) ) || is_page_template( 'page-full-width.php' ) || is_page_template( 'template-full-width-page.php' ) || is_page_template( 'template-full-width-post.php' ) || is_404() ) {
        $content_width = 1072;
    }

    $GLOBALS['content_width'] = apply_filters( 'cleanwp_content_width', $content_width ); /* phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound */
}
add_action( 'template_redirect', 'cleanwp_content_width', 0 );

function cleanwp_is_primary_menu_active() {
    $primary_menu_active = TRUE;

    if ( cleanwp_get_option('disable_primary_menu') ) {
        $primary_menu_active = FALSE;
    }

    return apply_filters( 'cleanwp_is_primary_menu_active', $primary_menu_active );
}

/**
 * Enqueue scripts and styles.
 */
function cleanwp_scripts() {
    wp_enqueue_style('cleanwp-maincss', get_stylesheet_uri(), array(), NULL);
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/css/all.min.css', array(), NULL );
    wp_enqueue_style('cleanwp-webfont', 'https://fonts.googleapis.com/css2?family=Domine:wght@400;700&family=Frank+Ruhl+Libre:wght@400;700&family=Oswald:wght@400;700&display=swap', array(), NULL);

    $cleanwp_primary_menu_active = FALSE;
    if ( cleanwp_is_primary_menu_active() ) {
        $cleanwp_primary_menu_active = TRUE;
    }

    wp_enqueue_script('cleanwp-navigation-js', get_template_directory_uri() . '/js/navigation.js', array(), NULL, true );
    wp_enqueue_script('cleanwp-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), NULL, true );
    wp_enqueue_script('cleanwp-customjs', get_template_directory_uri() .'/js/custom.js', array( 'jquery' ), NULL, true);

    wp_localize_script( 'cleanwp-customjs', 'cleanwp_ajax_object',
        array(
            'ajaxurl' => esc_url_raw( admin_url( 'admin-ajax.php' ) ),
            'primary_menu_active' => $cleanwp_primary_menu_active,
        )
    );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    wp_enqueue_script('cleanwp-html5shiv-js', get_template_directory_uri() .'/js/html5shiv.js', array('jquery'), NULL, true);

    wp_localize_script('cleanwp-html5shiv-js','cleanwp_custom_script_vars',array(
        'elements_name' => esc_html__('abbr article aside audio bdi canvas data datalist details dialog figcaption figure footer header hgroup main mark meter nav output picture progress section summary template time video', 'cleanwp'),
    ));
}
add_action( 'wp_enqueue_scripts', 'cleanwp_scripts' );

/**
 * Enqueue IE compatible scripts and styles.
 */
function cleanwp_ie_scripts() {
    wp_enqueue_script( 'respond', get_template_directory_uri(). '/js/respond.js', array(), NULL, false );
    wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );
}
add_action( 'wp_enqueue_scripts', 'cleanwp_ie_scripts' );

/**
 * Enqueue styles for the block-based editor.
 */
function cleanwp_block_editor_styles() {
    wp_enqueue_style( 'cleanwp-block-editor-style', get_template_directory_uri() . '/css/editor-blocks.css', array(), NULL );
}
add_action( 'enqueue_block_editor_assets', 'cleanwp_block_editor_styles' );

/**
 * Enqueue customizer styles.
 */
function cleanwp_enqueue_customizer_styles() {
    wp_enqueue_style( 'cleanwp-customizer-styles', get_template_directory_uri() . '/admin/css/customizer-styles.css', array(), NULL );
    wp_enqueue_style('fontawesome', get_template_directory_uri() . '/css/all.min.css', array(), NULL );
}
add_action( 'customize_controls_enqueue_scripts', 'cleanwp_enqueue_customizer_styles' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function cleanwp_widgets_init() {

register_sidebar(array(
    'id' => 'main-sidebar',
    'name' => esc_html__( 'Main Sidebar', 'cleanwp' ),
    'description' => esc_html__( 'This sidebar is located on the right-hand side of web page.', 'cleanwp' ),
    'before_widget' => '<div id="%1$s" class="side-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h3 class="widget-title">',
    'after_title' => '</h3>'));

register_sidebar(array(
    'id' => 'footer-1',
    'name' => esc_html__( 'Footer 1', 'cleanwp' ),
    'description' => esc_html__( 'This sidebar is located on the left bottom of web page.', 'cleanwp' ),
    'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h3 class="fwidget-title">',
    'after_title' => '</h3>'));

register_sidebar(array(
    'id' => 'footer-2',
    'name' => esc_html__( 'Footer 2', 'cleanwp' ),
    'description' => esc_html__( 'This sidebar is located on the middle bottom of web page.', 'cleanwp' ),
    'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h3 class="fwidget-title">',
    'after_title' => '</h3>'));

register_sidebar(array(
    'id' => 'footer-3',
    'name' => esc_html__( 'Footer 3', 'cleanwp' ),
    'description' => esc_html__( 'This sidebar is located on the right bottom of web page.', 'cleanwp' ),
    'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h3 class="fwidget-title">',
    'after_title' => '</h3>'));

}
add_action( 'widgets_init', 'cleanwp_widgets_init' );

// Get custom-logo URL
function cleanwp_custom_logo() {
    if ( ! has_custom_logo() ) {return;}
    $cleanwp_custom_logo_id = get_theme_mod( 'custom_logo' );
    $cleanwp_logo = wp_get_attachment_image_src( $cleanwp_custom_logo_id , 'full' );
    return $cleanwp_logo[0];
}

// Get our wp_nav_menu() fallback, wp_page_menu(), to show a "Home" link as the first item
function cleanwp_page_menu_args( $args ) {
    $args['show_home'] = true;
    return $args;
}
add_filter( 'wp_page_menu_args', 'cleanwp_page_menu_args' );

function cleanwp_primary_menu_text() {
   $menu_text = esc_html__( 'Menu', 'cleanwp' );
    if ( cleanwp_get_option('primary_menu_text') ) {
        $menu_text = cleanwp_get_option('primary_menu_text');
    }
    return apply_filters( 'cleanwp_primary_menu_text', $menu_text );
}

// Category ids in post class
function cleanwp_category_id_class($classes) {
        global $post;
        foreach((get_the_category($post->ID)) as $category)
            $classes [] = 'wpcat-' . $category->cat_ID . '-id';
            return $classes;
}
add_filter('post_class', 'cleanwp_category_id_class');

// Change excerpt length
function cleanwp_excerpt_length($length) {
    if ( is_admin() ) {
        return $length;
    }
    return 40;
}
add_filter('excerpt_length', 'cleanwp_excerpt_length');

// Change excerpt more word
function cleanwp_excerpt_more($more) {
    global $post;
    if ( is_admin() ) {
        return $more;
    }
    $readmoretext = esc_html__( 'Read More', 'cleanwp' );
    if ( cleanwp_get_option('read_more_text') ) {
            $readmoretext = cleanwp_get_option('read_more_text');
    }
    if( empty($post) ) {
        return;
    }
    return '<div class="entry-read-more"><a class="read-more-link" href="'. esc_url( get_permalink($post->ID) ) . '">'.$readmoretext.'<span class="cleanwp-sr-only">  '.wp_kses_post( get_the_title() ).'</span></a></div>';
}
add_filter('excerpt_more', 'cleanwp_excerpt_more');

// Adds custom classes to the array of body classes.
function cleanwp_body_classes( $classes ) {
    // Adds a class of group-blog to blogs with more than 1 published author.
    if ( is_multi_author() ) {
        $classes[] = 'group-blog';
    }
    if ( get_header_image() ) {
        $classes[] = 'cleanwp-header-image-active';
    }
    if ( has_custom_logo() ) {
        $classes[] = 'cleanwp-custom-logo-active';
    }
    if ( cleanwp_is_primary_menu_active() ) {
        $classes[] = 'cleanwp-primary-menu-active';
    }
    if ( ( ! is_active_sidebar( 'main-sidebar' ) ) || is_page_template( 'page-full-width.php' ) || is_page_template( 'template-full-width-page.php' ) || is_page_template( 'template-full-width-post.php' ) || is_404() ) {
        $classes[] = 'body-full-width';
    }
    return $classes;
}
add_filter( 'body_class', 'cleanwp_body_classes' );

/**
 * Register Custom Block Styles
 */
if ( function_exists( 'register_block_style' ) ) :
    function cleanwp_register_block_styles() {

        /**
         * Register block style
         */
        register_block_style( 'core/button', array( 'name' => 'cleanwp-button', 'label' => __( 'CleanWP Button', 'cleanwp' ), 'is_default' => true, 'style_handle' => 'cleanwp-maincss', ) ); // phpcs:ignore WPThemeReview.PluginTerritory.ForbiddenFunctions.editor_blocks_register_block_style

    }
    add_action( 'init', 'cleanwp_register_block_styles' );
endif;

/**
 * Other theme functions
 */
require_once( trailingslashit( get_template_directory() ) . 'admin/template-tags.php' );
require_once( trailingslashit( get_template_directory() ) . 'admin/custom-hooks.php' );
require_once( trailingslashit( get_template_directory() ) . 'admin/custom.php' );